-- =============================================
-- SaveToDB Framework for MySQL
-- Version 8.7, March 12, 2018
--
-- This script upgrades SaveToDB Framework 8.0 to SaveToDB Framework 8.6
--
-- Copyright 2013-2018 Gartle Technology Corporation
-- =============================================

CREATE OR REPLACE VIEW xls.queries
AS
SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TABLE_TYPE
    , NULL AS TABLE_CODE
    , NULL AS INSERT_PROCEDURE
    , NULL AS UPDATE_PROCEDURE
    , NULL AS DELETE_PROCEDURE
    , NULL AS PROCEDURE_TYPE
FROM
    information_schema.tables t
WHERE
    NOT t.TABLE_SCHEMA IN ('information_schema', 'mysql', 'performance_schema', 'xls', 'savetodb_dev', 'savetodb_xls')
    AND NOT t.TABLE_NAME LIKE 'xl_%'
UNION ALL
SELECT
    r.ROUTINE_SCHEMA AS TABLE_SCHEMA
    , r.ROUTINE_NAME AS TABLE_NAME
    , r.ROUTINE_TYPE AS TABLE_TYPE
    , NULL AS TABLE_CODE
    , NULL AS INSERT_PROCEDURE
    , NULL AS UPDATE_PROCEDURE
    , NULL AS DELETE_PROCEDURE
    , NULL AS PROCEDURE_TYPE
FROM 
    information_schema.routines r
WHERE
    NOT r.ROUTINE_SCHEMA IN ('information_schema', 'mysql', 'performance_schema', 'xls', 'savetodb_dev', 'savetodb_xls')
    AND r.ROUTINE_TYPE = 'PROCEDURE'
    AND NOT (
        r.ROUTINE_NAME LIKE '%_insert'
        OR r.ROUTINE_NAME LIKE '%_update'
        OR r.ROUTINE_NAME LIKE '%_delete'
        OR r.ROUTINE_NAME LIKE '%_merge'
        OR r.ROUTINE_NAME LIKE '%_change'
        OR r.ROUTINE_NAME LIKE 'xl_%'
    )
UNION ALL
SELECT
    o.TABLE_SCHEMA
    , o.TABLE_NAME
    , o.TABLE_TYPE
    , o.TABLE_CODE
    , o.INSERT_OBJECT AS INSERT_PROCEDURE
    , o.UPDATE_OBJECT AS UPDATE_PROCEDURE
    , o.DELETE_OBJECT AS DELETE_PROCEDURE
    , NULL AS PROCEDURE_TYPE
FROM
    xls.objects o
WHERE
    o.TABLE_TYPE IN ('CODE', 'HTTP', 'TEXT')
    AND o.TABLE_SCHEMA IS NOT NULL
    AND o.TABLE_NAME IS NOT NULL
    AND o.TABLE_CODE IS NOT NULL
ORDER BY
    TABLE_SCHEMA
    , TABLE_NAME;

UPDATE xls.handlers SET HANDLER_CODE = 'TABLE, VIEW, PROCEDURE, CODE, HTTP, TEXT, HIDDEN'
    WHERE TABLE_SCHEMA = 'xls' AND TABLE_NAME = 'objects' AND COLUMN_NAME = 'TABLE_TYPE' AND EVENT_NAME = 'ValidationList' AND HANDLER_TYPE = 'VALUES';
UPDATE xls.handlers SET HANDLER_CODE = 'Actions, Change, ContextMenu, DoubleClick, SelectionChange, ConvertFormulas, DoNotConvertFormulas, DoNotSelect, DoNotSave, DoNotChange, ProtectRows, Formula, FormulaValue, ParameterValues, ValidationList, SelectionList, SyncParameter, DefaultListObject'
    WHERE TABLE_SCHEMA = 'xls' AND TABLE_NAME = 'handlers' AND COLUMN_NAME = 'EVENT_NAME' AND EVENT_NAME = 'ValidationList' AND HANDLER_TYPE = 'VALUES';
UPDATE xls.handlers SET HANDLER_CODE = 'TABLE, VIEW, PROCEDURE, FUNCTION, CODE, HTTP, TEXT, MACRO, CMD, VALUES, RANGE, REFRESH, MENUSEPARATOR, PDF, REPORT'
    WHERE TABLE_SCHEMA = 'xls' AND TABLE_NAME = 'handlers' AND COLUMN_NAME = 'HANDLER_TYPE' AND EVENT_NAME = 'ValidationList' AND HANDLER_TYPE = 'VALUES';
